@@ -184,6 +184,9 @@ local grammars = {
     tex  = contextgrammar,
     mkii = contextgrammar,
     mkiv = contextgrammar,
+    mkvi = contextgrammar,
+    mkil = contextgrammar,
+    mkli = contextgrammar,
 }
 
 function validator.check(str,filetype)
