@@ -16,7 +16,7 @@ local round = math.round
 local concat = table.concat
 local suffixonly = file.suffix
 
-local newreader         = io.newreader
+local newreader         = io.newreader               -- needs checking 0/1 based
 local setmetatableindex = table.setmetatableindex
 local setmetatablecall  = table.setmetatablecall
 
@@ -24,6 +24,15 @@ local graphics       = graphics or { }
 local identifiers    = { }
 graphics.identifiers = identifiers
 
+local function checkedmethod(filename,method)
+    if method ~= "string" then
+        local found, data = resolvers.loadbinfile(filename)
+        return data, "string"
+    else
+        return filename, method
+    end
+end
+
 do
 
     local colorspaces = {
@@ -97,6 +106,13 @@ do
         [0x01] = { name = "TEM",  zerolength = true }, -- temporary use
     }
 
+    setmetatableindex(tags, function(t,k)
+        -- we can add some tracing if needed (global) to get an idea
+        local v = "tag " .. k
+        t[k] = v
+        return v
+    end)
+
     -- More can be found in http://www.exif.org/Exif2-2.PDF but basically we have
     -- good old tiff tags here.
 
@@ -215,6 +231,7 @@ do
             specification.error = "invalid filename"
             return specification -- error
         end
+        filename, method = checkedmethod(filename,method)
         local f = newreader(filename,method)
         if not f then
             specification.error = "unable to open file"
@@ -254,7 +271,7 @@ do
             local length    = 0
             local tagdata   = tags[category]
             if not tagdata then
-                specification.error = "invalid tag"
+                specification.error = "invalid tag " .. (category or "?")
                 break
             elseif tagdata.supported == false then
                 specification.error = "unsupported " .. tagdata.comment
@@ -447,6 +464,7 @@ do
             specification.error = "invalid filename"
             return specification -- error
         end
+        filename, method = checkedmethod(filename,method)
         local f = newreader(filename,method)
         if not f then
             specification.error = "unable to open file"
@@ -551,6 +569,7 @@ do
             specification.error = "invalid filename"
             return specification -- error
         end
+        filename, method = checkedmethod(filename,method)
         local f = newreader(filename,method)
         if not f then
             specification.error = "unable to open file"
@@ -602,8 +621,11 @@ do
                 local y = f:readcardinal4()
                 local u = f:readcardinal()
                 if u == 1 then -- meters
-                 -- x = round(0.0254 * x)
-                 -- y = round(0.0254 * y)
+                    -- there was a reason why this was commented
+                    x = round(0.0254 * x)
+                    y = round(0.0254 * y)
+                    if x == 0 then x = 1 end
+                    if y == 0 then y = 1 end
                 end
                 specification.xres = x
                 specification.yres = y
@@ -717,21 +739,18 @@ end
 
 function graphics.identify(filename,filetype)
     local identify = filetype and identifiers[filetype]
+    if not identify then
+        identify = identifiers[suffixonly(filename)]
+    end
     if identify then
         return identify(filename)
-    end
-    local identify = identifiers[suffixonly(filename)]
-    if identify then
-        identify = identify(filename)
     else
-        identify = {
+        return {
             filename = filename,
             filetype = filetype,
             error    = "identification failed",
         }
     end
- -- inspect(identify)
-    return identify
 end
 
 -- inspect(identifiers.jpg("t:/sources/hacker.jpg"))
