@@ -16,7 +16,9 @@ local pdfconstant        = lpdf.constant
 local pdfdictionary      = lpdf.dictionary
 local pdfarray           = lpdf.array
 local pdfborder          = lpdf.border
-local write_node         = node.write
+
+-- We should actually make sure that inclusion only happens once. But this mechanism
+-- is dropped in pdf anyway so it will go away (read: mapped onto the newer mechanisms).
 
 function nodeinjections.insertmovie(specification)
     -- managed in figure inclusion: width, height, factor, repeat, controls, preview, label, foundname
@@ -24,7 +26,7 @@ function nodeinjections.insertmovie(specification)
     local height = specification.height
     local factor = specification.factor or number.dimenfactors.bp
     local moviedict = pdfdictionary {
-        F      = specification.foundname,
+        F      = specification.foundname or specification.file,
         Aspect = pdfarray { factor * width, factor * height },
         Poster = (specification.preview and true) or false,
     }
@@ -37,32 +39,31 @@ function nodeinjections.insertmovie(specification)
         Subtype = pdfconstant("Movie"),
         Border  = bs,
         C       = bc,
-        T       = format("movie %s",specification.label),
+        T       = format("movie %s",specification.tag or specification.label),
         Movie   = moviedict,
         A       = controldict,
     }
-    write_node(nodeinjections.annotation(width,height,0,action())) -- test: context(...)
+    context(nodeinjections.annotation(width,height,0,action())) -- test: context(...)
 end
 
 function nodeinjections.insertsound(specification)
-    -- managed in interaction: repeat, label, foundname
-    local soundclip = interactions.soundclips.soundclip(specification.label)
-    if soundclip then
-        local controldict = pdfdictionary {
-            Mode = (specification["repeat"] and pdfconstant("Repeat")) or nil
+    local controldict = nil
+    if specification["repeat"] then
+        controldict = pdfdictionary {
+            Mode = pdfconstant("Repeat")
         }
-        local sounddict = pdfdictionary {
-            F = soundclip.filename
-        }
-        local bs, bc = pdfborder()
-        local action = pdfdictionary {
-            Subtype = pdfconstant("Movie"),
-            Border  = bs,
-            C       = bc,
-            T       = format("sound %s",specification.label),
-            Movie   = sounddict,
-            A       = controldict,
-        }
-        write_node(nodeinjections.annotation(0,0,0,action())) -- test: context(...)
     end
+    local sounddict = pdfdictionary {
+        F = specification.foundname or specification.file
+    }
+    local bs, bc = pdfborder()
+    local action = pdfdictionary {
+        Subtype = pdfconstant("Movie"),
+        Border  = bs,
+        C       = bc,
+        T       = format("sound %s",specification.tag or specification.label),
+        Movie   = sounddict,
+        A       = controldict,
+    }
+    context(nodeinjections.annotation(0,0,0,action())) -- test: context(...)
 end
